@@ -129,13 +129,12 @@ To ensure control over the rerender process, it is recommended to :func:`Element
 whenever you have many children of the same class.
 """
 
-from ._component import Element, component, Reference
+from .engine import QtWidgetElement, Element, component, Reference
 from .app import App
 from .utilities import alert, file_dialog, set_trace
-from .hooks import use_state, use_effect, use_async, use_ref, use_async_call
+from .hooks import use_state, use_effect, use_async, use_ref, use_async_call, use_effect_final
 
 from .base_components import (
-    QtWidgetElement,
     Window,
     ExportList,
     View,
@@ -148,6 +147,7 @@ from .base_components import (
     IconButton,
     Button,
     TextInput,
+    TextInputMultiline,
     CheckBox,
     RadioButton,
     Slider,
@@ -174,6 +174,7 @@ __all__ = [
     "use_async",
     "use_ref",
     "use_async_call",
+    "use_effect_final",
     "QtWidgetElement",
     "Window",
     "ExportList",
@@ -187,6 +188,7 @@ __all__ = [
     "IconButton",
     "Button",
     "TextInput",
+    "TextInputMultiline",
     "CheckBox",
     "RadioButton",
     "Slider",
